@@ -7,19 +7,14 @@ from tempfile import TemporaryDirectory
 from cognite.client import CogniteClient
 from cognite.experimental import CogniteClient as ExperimentalClient
 
-from cognite.airworkflow.constants import PROJECTS_TO_API_KEYS
+from cognite.airworkflow.constants import AUTHENTICATION, COGNITE_CLIENT_NAME
 
 os.environ["COGNITE_MAX_RETRIES"] = "5"
 os.environ["COGNITE_TIMEOUT"] = "120"
 
 
 def data_set_id(client: CogniteClient, name: str) -> int:
-    data_sets = client.data_sets.list(limit=-1).dump()
-    for ds in data_sets:
-        if "name" in ds:
-            if ("archived" not in ds["metadata"] or ds["metadata"]["archived"] != "true") and ds["name"] == name:
-                return ds["id"]
-    raise LookupError(f"Not able to find dataset named {name}")
+    return client.data_sets.retrieve(external_id=name).id
 
 
 def zip_and_upload(client: CogniteClient, code_path: Path, file_name: str, data_set_name: str) -> int:
@@ -63,10 +58,23 @@ def await_function_deployment(client: ExperimentalClient, function_name: str, ma
     return False
 
 
-def experimental_client(project: str, api_key: str = "", base_url: str = None) -> ExperimentalClient:
-    return ExperimentalClient(
-        api_key=api_key if api_key else PROJECTS_TO_API_KEYS[project].get_client_api_key(),
-        client_name="AIR Functions Client",
-        project=project,
-        base_url=base_url if base_url else PROJECTS_TO_API_KEYS[project].base_url,
-    )
+def experimental_client(project: str) -> ExperimentalClient:
+    project_auth = AUTHENTICATION[project]
+    if project_auth.oidc:
+        experimental_client = ExperimentalClient(
+            token_url=project_auth.token_url,
+            token_client_id=project_auth.client_id,
+            token_client_secret=project_auth.get_client_secret(),
+            token_scopes=project_auth.scopes,
+            project=project,
+            base_url=project_auth.base_url,
+            client_name=COGNITE_CLIENT_NAME,
+        )
+    else:
+        experimental_client = ExperimentalClient(
+            api_key=project_auth.get_client_api_key(),
+            client_name=COGNITE_CLIENT_NAME,
+            project=project,
+            base_url=project_auth.base_url,
+        )
+    return experimental_client
